@@ -16,6 +16,7 @@ from __future__ import absolute_import
 
 from .select_command import SelectCommand
 from .set_state_command import SetStateCommand
+from .hide_overlay_command import HideOverlayCommand
 from .rendered_document_state import RenderedDocumentState
 from .play_media_command import PlayMediaCommand
 from .update_index_list_data_directive import UpdateIndexListDataDirective
@@ -42,9 +43,11 @@ from .scroll_command import ScrollCommand
 from .component_visible_on_screen_scrollable_tag import ComponentVisibleOnScreenScrollableTag
 from .control_media_command import ControlMediaCommand
 from .scroll_to_index_command import ScrollToIndexCommand
+from .show_overlay_command import ShowOverlayCommand
 from .set_page_command import SetPageCommand
 from .skew_transform_property import SkewTransformProperty
 from .video_source import VideoSource
+from .back_type import BackType
 from .alexa_presentation_apl_interface import AlexaPresentationAplInterface
 from .auto_page_command import AutoPageCommand
 from .send_event_command import SendEventCommand
@@ -67,6 +70,7 @@ from .finish_command import FinishCommand
 from .runtime_error_event import RuntimeErrorEvent
 from .idle_command import IdleCommand
 from .load_index_list_data_event import LoadIndexListDataEvent
+from .go_back_command import GoBackCommand
 from .set_focus_command import SetFocusCommand
 from .speak_list_command import SpeakListCommand
 from .parallel_command import ParallelCommand
